@@ -11,20 +11,26 @@ use CPAN::Packager::Home;
 use CPAN::Packager::Builder::RPM::Spec;
 use CPAN::Packager::Util;
 with 'CPAN::Packager::Builder::Role';
-with 'CPAN::Packager::Role::Logger';
+use Log::Log4perl qw(:easy);
 
 has 'package_output_dir' => (
-    +default => sub {
-        my $self = shift;
+    is      => 'rw',
+    default => sub {
         dir( CPAN::Packager::Home->detect, 'rpm' );
     },
 );
 
+has 'is_debug' => (
+    is      => 'rw',
+    lazy    => 1,
+    default => sub { get_logger('')->level() == $DEBUG }
+);
+
 has 'build_dir' => (
     is      => 'rw',
     default => sub {
         my %opt = ( CLEANUP => 1, DIR => '/tmp' );
-        %opt = ( DIR => '/tmp' ) if &CPAN::Packager::DEBUG;
+        %opt = ( DIR => '/tmp' ) if ( shift->is_debug );
         my $tmpdir = tempdir(%opt);
         dir($tmpdir);
     }
@@ -47,10 +53,10 @@ sub BUILD {
 sub check_executables_exist_in_path {
     die "cpanflute2 doesn't exist in PATH"
         if CPAN::Packager::Util::run_command("which cpanflute2");
-    die "yum doesn't  exist in PATH"
-        if CPAN::Packager::Util::run_command("which cpanflute2");
-    die "rpm doesn't  exist in PATH"
-        if CPAN::Packager::Util::run_command("which cpanflute2");
+    die "yum doesn't exist in PATH"
+        if CPAN::Packager::Util::run_command("which yum");
+    die "rpm doesn't exist in PATH"
+        if CPAN::Packager::Util::run_command("which rpm");
 }
 
 sub build {
@@ -59,8 +65,8 @@ sub build {
         "$module->{module} does't have tarball. we can't find $module->{module} in CPAN "
         unless $module->{tgz};
 
-    $self->release($module->{release}) if $module->{release};
-    $self->pkg_name($module->{pkg_name}) if $module->{pkg_name};
+    $self->release( $module->{release} )   if $module->{release};
+    $self->pkg_name( $module->{pkg_name} ) if $module->{pkg_name};
 
     my ( $spec_file_name, $spec_content )
         = $self->generate_spec_file($module);
@@ -69,15 +75,14 @@ sub build {
     $self->copy_module_sources_to_build_dir($module);
     my $is_failed = $self->build_rpm_package($spec_file_name);
     $self->install($module) unless $is_failed;
-    $self->log(
-        info => ">>> finished building rpm package ( $module->{module} )" );
+    INFO(">>> finished building rpm package ( $module->{module} )");
     return $self->get_package_name($module);
 }
 
 sub get_spec_name {
-    my ($self, $module) = @_; 
+    my ( $self, $module ) = @_;
     my $package_name = $self->get_package_name($module);
-    my $spec_name = $package_name . ".spec";
+    my $spec_name    = $package_name . ".spec";
     return $spec_name;
 }
 
@@ -89,9 +94,8 @@ sub generate_spec_file {
     $spec_content
         = $self->filter_spec_file( $spec_content, $module->{module} );
 
-    $self->log( info => ">>> generated specfile : \n $spec_content" )
-        if $self->config( global => 'verbose' );
     $self->create_spec_file( $spec_content, $spec_file_name );
+    DEBUG("Generated specfile:\n-----\n$spec_content");
     ( $spec_file_name, $spec_content );
 }
 
@@ -99,14 +103,14 @@ sub generate_spec_with_cpanflute {
     my ( $self, $module ) = @_;
 
     my $tgz = $module->{tgz};
-    $self->log( info => '>>> generate specfile with cpanflute2 for ' . $tgz );
+    INFO( 'generating specfile with cpanflute2 for ' . $tgz );
 
     my $module_name = $module->{module};
     my $version     = $module->{version};
     my $basename    = fileparse($tgz);
     my $distro      = CPAN::DistnameInfo->new($basename);
     my $ext         = $distro->extension;
-    my $copy_to = file( $self->build_dir, "$module_name-$version.$ext" );
+    my $copy_to     = file( $self->build_dir, "$module_name-$version.$ext" );
     copy( $module->{tgz}, $copy_to );
 
     $ENV{LANG} = 'C';
@@ -120,18 +124,20 @@ sub generate_spec_with_cpanflute {
         'tmpdir'      => $self->build_dir,
         'pkg_name'    => $self->pkg_name,
         'epoch'       => $module->{epoch},
+        'patchdir'    => $self->build_dir,
     };
 
     $opts->{test} = 0 if $module->{skip_test};
 
-    if(defined $module->{custom} and defined $module->{custom}->{patches}) {
+    if ( defined $module->{custom} and defined $module->{custom}->{patches} )
+    {
         $opts->{patch} = $module->{custom}->{patches};
     }
 
-    my $spec = $self->spec_builder->build( $opts, $copy_to, $self->build_dir );
-
-    $self->log( info => '>>> generated specfile for ' . $tgz );
+    my $spec
+        = $self->spec_builder->build( $opts, $copy_to, $self->build_dir );
     $spec;
+
 }
 
 sub filter_spec_file {
@@ -154,7 +160,7 @@ sub create_spec_file {
     $fh->close;
     copy( $spec_file_path,
         file( $self->package_output_dir, $spec_file_name ) );
-
+    DEBUG( "Wrote out: " . $self->package_output_dir . "/$spec_file_name" );
 }
 
 sub filter_requires_for_rpmbuild {
@@ -212,8 +218,7 @@ sub _prefix_obsoletes {
             @{ $self->config( modules => $module )->{obsoletes} || () } )
         {
             $spec_content
-                = "Obsoletes: $obsolete->{package}\n"
-                . $spec_content;
+                = "Obsoletes: $obsolete->{package}\n" . $spec_content;
         }
     }
     $spec_content;
@@ -306,7 +311,8 @@ sub is_installed {
     my $package;
 
     if (   $self->config( modules => $module )
-        && $self->config( modules => $module )->{pkg_name} ) {
+        && $self->config( modules => $module )->{pkg_name} )
+    {
         $package = $self->config( modules => $module )->{pkg_name};
     }
     else {
@@ -315,10 +321,12 @@ sub is_installed {
 
     my $return_value
         = CPAN::Packager::Util::capture_command("LANG=C rpm -q $package");
-    $self->log( info => ">>> $package is "
-            . ( $return_value =~ /not installed/ ? 'not ' : '' )
-            . "installed" );
-    return $return_value =~ /not installed/ ? 0 : 1;
+    if ( $return_value =~ /not installed/ ) {
+        DEBUG("$package is not installed");
+        return 0;
+    }
+    INFO("$package is installed:");
+    return 1;
 }
 
 sub generate_macro {
@@ -350,6 +358,10 @@ sub generate_rpmrc {
     my $macrofiles = qx(rpm --showrc | grep ^macrofiles | cut -f2- -d:);
     chomp $macrofiles;
     my $build_dir = $self->build_dir;
+    ( -r '/usr/lib/rpm/rpmrc' )
+        or die(
+        'File "/usr/lib/rpm/rpmrc" does not exist or is not readable. cannot proceed'
+        );
     print $fh qq{
 include: /usr/lib/rpm/rpmrc
 macrofiles: $macrofiles:$build_dir/macros
@@ -359,14 +371,14 @@ macrofiles: $macrofiles:$build_dir/macros
 
 sub build_rpm_package {
     my ( $self, $spec_file_name ) = @_;
-    $self->log( info => '>>> build rpm package with rpmbuild' );
+    INFO('>>> build rpm package with rpmbuild');
     my $rpmrc_file     = file( $self->build_dir, 'rpmrc' );
     my $spec_file_path = file( $self->build_dir, $spec_file_name );
 
     my $build_opt
         = "--rcfile $rpmrc_file -ba --rmsource --rmspec --clean $spec_file_path --nodeps";
     $build_opt = "--rcfile $rpmrc_file -ba $spec_file_path"
-        if &CPAN::Packager::DEBUG;
+        if ( $self->is_debug );
     my $cmd = "env PERL_MM_USE_DEFAULT=1 LANG=C rpmbuild $build_opt";
     return CPAN::Packager::Util::run_command( $cmd,
         $self->config( global => "verbose" ) );
@@ -383,8 +395,7 @@ sub copy_module_sources_to_build_dir {
 
     $module_name =~ s{::}{-}g;
     my $version = $module->{version};
-    copy( $module_tarball,
-        file( $build_dir, "$module_name-$version.$ext" ) );
+    copy( $module_tarball, file( $build_dir, "$module_name-$version.$ext" ) );
 }
 
 sub package_name {
@@ -400,7 +411,7 @@ sub installed_packages {
         = CPAN::Packager::Util::run_command(
         "LANG=C yum list installed|grep '^perl\-*' |awk '{print \$1}'",
         $self->config( global => "verbose" ) );
-    my @packages = split /[\r\n]+/, $return_value;
+    my @packages = split /[\r\n]+/, $return_value;    #/
     for my $package (@packages) {
         push @installed_pkg, $package;
     }
@@ -417,12 +428,13 @@ sub print_installed_packages {
 
 sub install {
     my ( $self, $module ) = @_;
-    my $module_name  = $module->{module};
+    my $module_name    = $module->{module};
     my $module_version = $module->{version};
-    my $package_name = $self->get_package_name($module_name);
+    my $package_name = $self->get_package_name($module);
 
-    $self->log( info => ">>> install $package_name-$module_version" );
-    my $rpm_path = file( $self->package_output_dir, "$package_name-$module_version" );
+    INFO(">>> install $package_name-$module_version");
+    my $rpm_path
+        = file( $self->package_output_dir, "$package_name-$module_version" );
     my $result = CPAN::Packager::Util::run_command(
         "sudo rpm -Uvh $rpm_path-*.rpm",
         $self->config( global => "verbose" )
